==> zio-aws-ec2_2.12-7.21.15.11-sources.jar: zio/aws/ec2/model/DeleteSecurityGroupRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{SecurityGroupName, SecurityGroupId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteSecurityGroupRequest(
    groupId: Optional[SecurityGroupId] = Optional.Absent,
    groupName: Optional[SecurityGroupName] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest = {
    import DeleteSecurityGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest
      .builder()
      .optionallyWith(
        groupId.map(value => SecurityGroupId.unwrap(value): java.lang.String)
      )(_.groupId)
      .optionallyWith(
        groupName.map(value =>
          SecurityGroupName.unwrap(value): java.lang.String
        )
      )(_.groupName)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteSecurityGroupRequest.ReadOnly =
    zio.aws.ec2.model.DeleteSecurityGroupRequest.wrap(buildAwsValue())
}
object DeleteSecurityGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteSecurityGroupRequest =
      zio.aws.ec2.model.DeleteSecurityGroupRequest(
        groupId.map(value => value),
        groupName.map(value => value),
        dryRun.map(value => value)
      )
    def groupId: Optional[SecurityGroupId]
    def groupName: Optional[SecurityGroupName]
    def dryRun: Optional[Boolean]
    def getGroupId: ZIO[Any, AwsError, SecurityGroupId] =
      AwsError.unwrapOptionField("groupId", groupId)
    def getGroupName: ZIO[Any, AwsError, SecurityGroupName] =
      AwsError.unwrapOptionField("groupName", groupName)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest
  ) extends zio.aws.ec2.model.DeleteSecurityGroupRequest.ReadOnly {
    override val groupId: Optional[SecurityGroupId] = zio.aws.core.internal
      .optionalFromNullable(impl.groupId())
      .map(value => zio.aws.ec2.model.primitives.SecurityGroupId(value))
    override val groupName: Optional[SecurityGroupName] = zio.aws.core.internal
      .optionalFromNullable(impl.groupName())
      .map(value => zio.aws.ec2.model.primitives.SecurityGroupName(value))
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest
  ): zio.aws.ec2.model.DeleteSecurityGroupRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.127.1-sources.jar: zio/aws/ec2/model/DeleteSecurityGroupRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{SecurityGroupName, SecurityGroupId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteSecurityGroupRequest(
    groupId: Option[SecurityGroupId] = None,
    groupName: Option[SecurityGroupName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest = {
    import DeleteSecurityGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest
      .builder()
      .optionallyWith(
        groupId.map(value => SecurityGroupId.unwrap(value): java.lang.String)
      )(_.groupId)
      .optionallyWith(
        groupName.map(value =>
          SecurityGroupName.unwrap(value): java.lang.String
        )
      )(_.groupName)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.DeleteSecurityGroupRequest.ReadOnly =
    zio.aws.ec2.model.DeleteSecurityGroupRequest.wrap(buildAwsValue())
}
object DeleteSecurityGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DeleteSecurityGroupRequest =
      zio.aws.ec2.model.DeleteSecurityGroupRequest(
        groupId.map(value => value),
        groupName.map(value => value)
      )
    def groupId: Option[SecurityGroupId]
    def groupName: Option[SecurityGroupName]
    def getGroupId: ZIO[Any, AwsError, SecurityGroupId] =
      AwsError.unwrapOptionField("groupId", groupId)
    def getGroupName: ZIO[Any, AwsError, SecurityGroupName] =
      AwsError.unwrapOptionField("groupName", groupName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest
  ) extends zio.aws.ec2.model.DeleteSecurityGroupRequest.ReadOnly {
    override val groupId: Option[SecurityGroupId] = scala
      .Option(impl.groupId())
      .map(value => zio.aws.ec2.model.primitives.SecurityGroupId(value))
    override val groupName: Option[SecurityGroupName] = scala
      .Option(impl.groupName())
      .map(value => zio.aws.ec2.model.primitives.SecurityGroupName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DeleteSecurityGroupRequest
  ): zio.aws.ec2.model.DeleteSecurityGroupRequest.ReadOnly = new Wrapper(impl)
}
